==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ts/GraphicsViewPreferences_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Rulers and Scrollbars</source>
        <translation>定規及びスクロールバー</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show rulers</source>
        <translation>定規を表示</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show scrollbars</source>
        <translation>スクロールバーを表示</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Cursor</source>
        <translation>カーソル</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show crosshairs</source>
        <translation>十字線を表示</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show large crosshairs</source>
        <translation>大きな十字線を表示</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="obsolete">グリッド</translation>
    </message>
    <message>
        <source>Automatically scale grid</source>
        <translation type="obsolete">自動スケールグリッド</translation>
    </message>
    <message>
        <source>Solid grid lines</source>
        <translation type="obsolete">ソリッドグリッドライン</translation>
    </message>
    <message>
        <source>Minimal grid spacing (px):</source>
        <translation type="obsolete">最小グリッド間隔（ピクセル）:</translation>
    </message>
    <message>
        <source>Automatically scale meta grid</source>
        <translation type="obsolete">自動スケールメタグリッド</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Auto Zoom</source>
        <translation>オートズーム</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Margin (px):</source>
        <translation>マージン（ピクセル）:</translation>
    </message>
    <message>
        <location line="+57"/>
        <source>Color Adjustment</source>
        <translation>色調節</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Prevent white on white / black on black display</source>
        <translation>白に白/黒に黒の表示を防ぐ</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Color lightness threshold:</source>
        <translation>色の明るさ閾値:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Linetypes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Pattern scale for lineweight 0.00mm:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Automatically use screen based linetypes in model view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Auto switch linetypes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Performance</source>
        <translation>パフォーマンス</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Number of preview entities:</source>
        <translation>プレビューエンティティの数:</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Text height display threshold (px):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display arcs as lines below this angle (degrees):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translation type="obsolete">テキスト高さの表示閾値:</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Selection</source>
        <translation>選択</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Persistent Selection</source>
        <translation>選択を持続</translation>
    </message>
</context>
<context>
    <name>GraphicsViewPreferences</name>
    <message>
        <location filename="../GraphicsViewPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>グラフィックビュー</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Appearance</source>
        <translation>外見</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ts/GraphicsViewPreferences_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+51"/>
        <source>Rulers and Scrollbars</source>
        <translation>定規及びスクロールバー</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show rulers</source>
        <translation>定規を表示</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show scrollbars</source>
        <translation>スクロールバーを表示</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Cursor</source>
        <translation>カーソル</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show crosshairs</source>
        <translation>十字線を表示</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show large crosshairs</source>
        <translation>大きな十字線を表示</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="obsolete">グリッド</translation>
    </message>
    <message>
        <source>Automatically scale grid</source>
        <translation type="obsolete">自動スケールグリッド</translation>
    </message>
    <message>
        <source>Solid grid lines</source>
        <translation type="obsolete">ソリッドグリッドライン</translation>
    </message>
    <message>
        <source>Minimal grid spacing (px):</source>
        <translation type="obsolete">最小グリッド間隔（ピクセル）:</translation>
    </message>
    <message>
        <source>Automatically scale meta grid</source>
        <translation type="obsolete">自動スケールメタグリッド</translation>
    </message>
    <message>
        <location line="-64"/>
        <source>Origin</source>
        <translation>原点</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show large origin axis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+71"/>
        <source>Auto Zoom</source>
        <translation>オートズーム</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Margin (px):</source>
        <translation>マージン（ピクセル）:</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Auto zoom on load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Color Adjustment</source>
        <translation>色調節</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Prevent white on white / black on black display</source>
        <translation>白に白/黒に黒の表示を防ぐ</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Color lightness threshold:</source>
        <translation>色の明るさ閾値:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Linetypes</source>
        <translation>ラインタイプ</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Auto switch to screen based linetypes in model view</source>
        <translation>自動的にモデルビューの基本線種を使用</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale linetype patterns by line weight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Pattern scale for lineweight 0.00mm:</source>
        <translation>線の太さのパターン·スケール 0.00mm:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Display and Performance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+146"/>
        <source>Display entities with more than N dashes as continuous:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Minimum angle step for rendering arcs (degrees):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+144"/>
        <source>Use full resolution for Retina display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Anti-aliasing on by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Maximum number of reference points displayed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-76"/>
        <source>Timeout for hatch rendering:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-342"/>
        <source>Automatically use screen based linetypes in model view</source>
        <translation>自動的にモデルビューの基本線種を使用</translation>
    </message>
    <message>
        <source>Auto switch linetypes</source>
        <translation type="obsolete">ラインタイプの自動切り替え</translation>
    </message>
    <message>
        <source>Performance</source>
        <translation type="vanished">パフォーマンス</translation>
    </message>
    <message>
        <location line="+78"/>
        <source>Number of preview entities:</source>
        <translation>プレビューエンティティの数:</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Text height display threshold (px):</source>
        <translation>テキスト高さの表示しきい値 (px):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display arcs as lines below this angle (degrees):</source>
        <translation>この角度以下の弧を直線で表示 (度):</translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translation type="obsolete">テキスト高さの表示閾値:</translation>
    </message>
    <message>
        <location line="+331"/>
        <source>Selection</source>
        <translation>選択</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Persistent Selection</source>
        <translation>選択を持続</translation>
    </message>
</context>
<context>
    <name>GraphicsViewPreferences</name>
    <message>
        <location filename="../GraphicsViewPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>グラフィックビュー</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Appearance</source>
        <translation>外見</translation>
    </message>
</context>
</TS>
